@@ -94,7 +94,7 @@ class ConnectionBase(object):
         else:
             self._logger = logging.getLogger(type(self).__name__)
         self.default_timeout = default_timeout or 30
-        self.first_prompt_timeout = first_prompt_timeout or 120
+        self.first_prompt_timeout = int(first_prompt_timeout) if first_prompt_timeout else 120
         self.log("hi.")
 
     def log(self, msg):
@@ -117,12 +117,17 @@ class ConnectionBase(object):
         """ a wrapper for :pexpect:meth:`spawn.expect`
         """
         self.log("expect({},{},{})".format(
-            str(pattern).encode('string-escape'), timeout, searchwindowsize))
+            str(pattern).encode('string-escape'),
+            timeout,
+            searchwindowsize,
+        ))
         try:
             self.exp.expect(pattern, timeout, searchwindowsize)
             self.log("expect succeeded.")
         except Exception as e:
-            self.log("expect failed with '{}'".format(e.__class__.__name__))
+            self.log("expect failed with '{}'".format(
+                e.__class__.__name__,
+            ))
             raise e
 
     def _send(self, s):
@@ -186,18 +191,6 @@ class ConnectionBase(object):
         self.wait_for_prompt(self.first_prompt_timeout)
         prepped_msg = self._prep_cmdmessage(msg, do_retcode)
         self._sendline(prepped_msg)
-        # expect the last 10 characters of the cmd message
-        cmd_expect = [re.escape(prepped_msg[-10:]) + "[^\n]*\r\n"]
-        if expect and pexpect.EOF in expect:
-            cmd_expect.append(pexpect.EOF)
-        if expect and pexpect.TIMEOUT in expect:
-            cmd_expect.append(pexpect.TIMEOUT)
-        try:
-            self._expect(cmd_expect, timeout=0.1)
-        except (pexpect.EOF, pexpect.TIMEOUT) as e:
-            self._logger.warning("Couldn't read the command. Retrying just with last character.")
-            cmd_expect[0] = re.escape(prepped_msg[-1]) + "[^\n]*\r\n"
-            self._expect(cmd_expect, timeout=0.1)
         try:
             self._expect(expect or self.prompt, timeout=timeout or self.default_timeout)
             self._logger.debug("SUCCESS: cmd({}) result='{}' expect-match='{}'".format(
@@ -209,44 +202,64 @@ class ConnectionBase(object):
             self.log("caught EOF/TIMEOUT on last expect; closing connections")
             self.close()
             raise e
-        return self._prep_cmdoutput(self.exp.before, do_retcode)
+        return self._prep_cmdoutput(self.exp.before, prepped_msg, do_retcode)
 
     def _prep_cmdmessage(self, msg, do_retcode=True):
         """ prepares a command message before it is delivered to pexpect
 
         It might add retreiving a returncode and strips unnecessary whitespace.
         """
-        self.log("prep_msg({},{})".format(msg, do_retcode))
+        self.log("prep_msg({},{})".format(
+            str(msg).encode("string-escape"),
+            do_retcode,
+        ))
         # If the connection is a shell, you might want a returncode.
         # If it is not (like drbcc) then you might have no way to retreive a
         # returncode. Therefore make a decision here.
         get_retcode = '; echo "<retcode>$?</retcode>"' if do_retcode else ""
         # strip each line for unnecessary whitespace and delete empty lines
         prepped = "\n".join(line.strip() for line in msg.split("\n") if line.strip())
-        self.log("prepped:" + str(prepped+get_retcode))
-        return prepped + get_retcode
+        out = prepped+get_retcode
+        self.log("prepped:'{}'".format(
+            out.encode("string-escape"),
+        ))
+        return out
 
-    def _prep_cmdoutput(self, out, do_retcode=True):
+    def _prep_cmdoutput(self, out, cmd_expect, do_retcode=True):
         """ prepare the pexpect output for returning to the user
 
         Removing all the unnecessary "\r" characters and separates the
         returncode if one is requested.
         """
-        self.log("prep_out({},{})".format(out, do_retcode))
+        self.log("prep_out({},{})".format(
+            str(out).encode("string-escape"),
+            do_retcode,
+        ))
         if not out:
             self.log("out was empty and therefore couldn't be prepped.")
             return None, out
-        prepped_out = out.replace("\r","")
-        prepped_out = "\n".join(line.strip() for line in prepped_out.split("\n") if line.strip())
+        #remove shell line breaks
+        prepped_out = out.replace(" \r", "")
+        #remove the \r from \r\n
+        prepped_out = prepped_out.replace("\r","")
+        # remove cmd line
+        prepped_out = prepped_out.replace(cmd_expect + "\n", "")
         if do_retcode:
             try:
-                match = re.search("\n?<retcode>(\d+)</retcode>.*$", prepped_out)
+                match = re.search("\n?<retcode>(\d+)</retcode>.*\n", prepped_out)
+                self.log("found retcode string '{}'".format(
+                    str(match.group(0)).encode("string-escape"),
+                ))
                 retcode = int(match.group(1))
                 prepped_out = prepped_out.replace(match.group(0), "")
                 self.log("prepped with retcode")
                 return retcode, prepped_out
             except (AttributeError, IndexError) as e:
-                raise NoRetcodeException("failed to find retcode with '{}'".format(e.__class__.__name__))
+                self._logger.exception(e)
+                raise NoRetcodeException("failed to find retcode with '{}'. Formatted output:'{}'".format(
+                            e.__class__.__name__,
+                            prepped_out.encode("string-escape"),
+                ))
         else:
             self.log("prepped without retcode")
             return None, prepped_out
@@ -376,64 +389,3 @@ class SshConn(ConnectionBase):
                         e.__class__.__name__,
             ))
         super(SshConn, self).close()
-
-###############################################################
-#
-# Others - Connections that don't have a normal shell interface
-#
-###############################################################
-
-class BCC(ConnectionBase):
-
-    def __init__(self, port,
-            speed="57600",
-            name=None,
-            prompt="\r?\n?drbcc> ",
-            default_timeout=None
-        ):
-        if os.system("hash drbcc"):
-            raise NoBCCException("Please install the DResearch drbcc tool!")
-        self.name = name
-        self.port = port
-        self.speed = speed
-        self.prompt = prompt
-        super(BCC, self).__init__(default_timeout=default_timeout)
-
-    def cmd(self, msg, timeout=None, expect=None, login_timeout=None):
-        """ doesn't need a returncode
-        """
-        return super(BCC, self).cmd(
-                msg=msg,
-                expect=expect,
-                timeout=timeout,
-                do_retcode=False
-        )
-
-    def login(self,*args,**kwargs):
-        try:
-            super(BCC,self).login(*args,**kwargs)
-        except pexpect.EOF as e:
-            self._logger.exception(e)
-            raise BccException("EOF found. Did you configure the correct port?")
-
-    def _get_exp(self):
-        self.log("_get_exp('{}','{}')".format(
-                        self.port,
-                        self.speed,
-        ))
-        end_time = time.time() + self.first_prompt_timeout
-        while time.time() < end_time:
-            self.log("try opening drbcc connection")
-            try:
-                return pexpect.spawn("drbcc --dev={},{}".format(
-                                self.port,
-                                self.speed,
-                ))
-            except Exception as e:
-                self.log("wait a little before retry opening drbcc connection")
-                time.sleep(3)
-        raise CantCreateConn("tried for '{}' seconds".format(self.first_prompt_timeout))
-
-    def close(self):
-        self.log("force pexpect object to close")
-        self.exp.close(force=True)
